@@ -6,11 +6,12 @@ describe 'manila::network::neutron' do
       it 'configures manila network neutron' do
         is_expected.to contain_manila_config('neutron/insecure').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/auth_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_manila_config('neutron/auth_type').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/auth_type').with_value('password')
         is_expected.to contain_manila_config('neutron/cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/user_domain_name').with_value('Default')
         is_expected.to contain_manila_config('neutron/project_domain_name').with_value('Default')
         is_expected.to contain_manila_config('neutron/project_name').with_value('services')
+        is_expected.to contain_manila_config('neutron/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/endpoint_type').with_value('<SERVICE DEFAULT>')
@@ -26,7 +27,7 @@ describe 'manila::network::neutron' do
         {
           :insecure       => true,
           :auth_url       => 'http://127.0.0.2:5000/',
-          :auth_type      => 'password',
+          :auth_type      => 'v3password',
           :cafile         => '/etc/ssl/certs/ca.crt',
           :region_name    => 'RegionOne',
           :timeout        => 30,
@@ -39,14 +40,14 @@ describe 'manila::network::neutron' do
       end
 
       it 'configures manila neutron with overridden parameters' do
-      	is_expected.to contain_manila_config('DEFAULT/network_api_class').with_value('manila.network.neutron.neutron_network_plugin.NeutronNetworkPlugin')
         is_expected.to contain_manila_config('neutron/insecure').with_value(true)
         is_expected.to contain_manila_config('neutron/auth_url').with_value('http://127.0.0.2:5000/')
-        is_expected.to contain_manila_config('neutron/auth_type').with_value('password')
+        is_expected.to contain_manila_config('neutron/auth_type').with_value('v3password')
         is_expected.to contain_manila_config('neutron/cafile').with_value('/etc/ssl/certs/ca.crt')
         is_expected.to contain_manila_config('neutron/user_domain_name').with_value('Default')
         is_expected.to contain_manila_config('neutron/project_domain_name').with_value('Default')
         is_expected.to contain_manila_config('neutron/project_name').with_value('services')
+        is_expected.to contain_manila_config('neutron/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_manila_config('neutron/region_name').with_value('RegionOne')
         is_expected.to contain_manila_config('neutron/timeout').with_value(30)
         is_expected.to contain_manila_config('neutron/endpoint_type').with_value('publicURL')
@@ -56,6 +57,19 @@ describe 'manila::network::neutron' do
         is_expected.to contain_manila_config('DEFAULT/network_plugin_ipv6_enabled').with_value(true)
        end
     end
+
+    context 'when system_scope is set' do
+      let :params do
+        {
+          :system_scope => 'all'
+        }
+      end
+      it 'configures system-scoped credential' do
+        is_expected.to contain_manila_config('neutron/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/project_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_manila_config('neutron/system_scope').with_value('all')
+      end
+    end
   end
 
   on_supported_os({
