@@ -21,8 +21,8 @@ describe 'manila::share' do
       let :params do
         { 'manage_service' => false }
       end
-      it 'should not change the state of the service' do
-        is_expected.to contain_service('manila-share').without_ensure
+      it 'should not configure the service' do
+        is_expected.to_not contain_service('manila-share')
       end
     end
   end
