@@ -4,32 +4,27 @@ describe 'manila::backend::dellemc_unity' do
 
   let(:title) {'dellemc_unity'}
 
-  let :params do
+  let :required_params do
     {
-      :driver_handles_share_servers         => true,
-      :emc_nas_login                        => 'admin',
-      :emc_nas_password                     => 'password',
-      :emc_nas_server                       => '127.0.0.2',
-      :emc_share_backend                    => 'unity',
-      :unity_server_meta_pool               => 'pool1',
-      :unity_share_data_pools               => '*',
-      :unity_ethernet_ports                 => 'eth1',
-      :network_plugin_ipv6_enabled          => true,
-      :emc_ssl_cert_verify                  => true,
-      :emc_ssl_cert_path                    => '/etc/ssl/certs/',
-      :backend_availability_zone            => 'my_zone',
+      :driver_handles_share_servers => true,
+      :emc_nas_login                => 'admin',
+      :emc_nas_password             => 'password',
+      :emc_nas_server               => '127.0.0.2',
+      :unity_server_meta_pool       => 'pool1',
     }
   end
 
   let :default_params do
     {
-      :unity_server_meta_pool       => '<SERVICE DEFAULT>',
-      :unity_share_data_pools       => '<SERVICE DEFAULT>',
-      :unity_ethernet_ports         => '<SERVICE DEFAULT>',
-      :network_plugin_ipv6_enabled  => '<SERVICE DEFAULT>',
-      :emc_ssl_cert_verify          => '<SERVICE DEFAULT>',
-      :emc_ssl_cert_path            => '<SERVICE DEFAULT>',
-      :backend_availability_zone    => '<SERVICE DEFAULT>',
+      :emc_share_backend              => 'unity',
+      :unity_share_data_pools         => '<SERVICE DEFAULT>',
+      :unity_ethernet_ports           => '<SERVICE DEFAULT>',
+      :unity_share_server             => '<SERVICE DEFAULT>',
+      :report_default_filter_function => '<SERVICE DEFAULT>',
+      :network_plugin_ipv6_enabled    => true,
+      :emc_ssl_cert_verify            => false,
+      :emc_ssl_cert_path              => '<SERVICE DEFAULT>',
+      :backend_availability_zone      => '<SERVICE DEFAULT>',
     }
   end
 
@@ -53,20 +48,33 @@ describe 'manila::backend::dellemc_unity' do
 
   shared_examples 'manila::backend::dellemc_unity' do
     context 'with default parameters' do
-      before do
-        params = {}
+      let :params do
+        required_params
       end
 
       it_configures 'dell emc unity share driver'
     end
 
     context 'with provided parameters' do
+      let :params do
+        required_params.merge({
+          :unity_share_data_pools         => '*',
+          :unity_ethernet_ports           => 'eth1',
+          :unity_share_server             => '192.168.0.1',
+          :report_default_filter_function => false,
+          :network_plugin_ipv6_enabled    => true,
+          :emc_ssl_cert_verify            => true,
+          :emc_ssl_cert_path              => '/etc/ssl/certs/',
+          :backend_availability_zone      => 'my_zone',
+        })
+      end
+
       it_configures 'dell emc unity share driver'
     end
 
     context 'with share server config' do
-      before do
-        params.merge!({
+      let :params do
+        required_params.merge({
           :emc_nas_password => true,
         })
       end
