@@ -26,6 +26,17 @@ describe 'manila::backend::glusternfs' do
           is_expected.to contain_manila_config("gnfs/#{config}").with_value( value )
         end
       end
+
+      it 'installs gluster packages' do
+        is_expected.to contain_package(platform_params[:gluster_package_name]).with(
+          'ensure' => 'installed',
+          'tag'    => 'manila-support-package',
+        )
+        is_expected.to contain_package(platform_params[:gluster_client_package_name]).with(
+          'ensure' => 'installed',
+          'tag'    => 'manila-support-package',
+        )
+      end
     end
   end
 
@@ -37,6 +48,21 @@ describe 'manila::backend::glusternfs' do
         facts.merge!(OSDefaults.get_facts())
       end
 
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          {
+            :gluster_client_package_name => 'glusterfs-client',
+            :gluster_package_name        => 'glusterfs-common'
+          }
+        when 'RedHat'
+          {
+            :gluster_client_package_name => 'glusterfs-fuse',
+            :gluster_package_name        => 'glusterfs'
+          }
+        end
+      end
+
       it_behaves_like 'glusternfs volume driver'
     end
   end
